@@ -37,10 +37,10 @@ The =input block is used to specify pre-formatted keyboard input, which should b
 
 Export:
 
-* to docbook as B<screen> element
-* to html:
-        <pre class="screen-input">
-        </pre>
+* to docbook as B<userinput> element (L<http://www.docbook.org/tdg/en/html/userinput.html>)
+* to html (L<http://www.w3.org/TR/html401/struct/text.html#edef-KBD>):
+        <pre><kbd>
+        </kbd></pre>
 
 =cut
 
@@ -50,20 +50,21 @@ use Perl6::Pod::Block;
 use base 'Perl6::Pod::Block';
 
 sub to_xhtml {
-    my $self   = shift;
-    my $parser = shift;
-    my $el = 
-      $parser->mk_element('pre')->add_content( $parser->_make_elements(@_) );
-    $el->attrs_by_name->{class} = 'screen-input';
-    return $el;
+    my ( $self, $to ) = @_;
+    $to->w->raw('<pre><kbd>');
+    $self->{content} =
+          Perl6::Pod::Utl::parse_para( $self->childs->[0] );
+    $to->visit_childs($self);
+    $to->w->raw('</kbd></pre>');
 }
 
 sub to_docbook {
-    my $self   = shift;
-    my $parser = shift;
-    my $el =
-      $parser->mk_element('screen')->add_content( $parser->_make_elements(@_) );
-    return $el;
+    my ( $self, $to ) = @_;
+    $to->w->raw('<userinput>');
+    $self->{content} =
+          Perl6::Pod::Utl::parse_para( $self->childs->[0] );
+    $to->visit_childs($self);
+    $to->w->raw('</userinput>');
 }
 
 1;
@@ -77,6 +78,8 @@ L<http://zag.ru/perl6-pod/S26.html>,
 Perldoc Pod to HTML converter: L<http://zag.ru/perl6-pod/>,
 Perl6::Pod::Lib
 
+
+
 =head1 AUTHOR
 
 Zahatski Aliaksandr, <zag@cpan.org>
