@@ -4,23 +4,21 @@
 #
 #       AUTHOR:  Aliaksandr P. Zahatski, <zahatski@gmail.com>
 #===============================================================================
-#$Id$
 package T::FormattingCode::Z;
 use strict;
 use warnings;
 use Test::More;
 use Data::Dumper;
-use Perl6::Pod::To::XHTML;
 use base 'TBase';
 
 sub t01_as_xml : Test {
     my $t = shift;
-    my $x = $t->parse_to_xml( <<T);
+    my $x = $t->parse_to_xhtml( <<T);
 =para
 The Z<TWEST>
 T
-is $x,q#<para pod:type='block' xmlns:pod='http://perlcabal.org/syn/S26.html'>The 
-</para>#;
+is $x,q#<xhtml xmlns="http://www.w3.org/1999/xhtml"><p>The 
+</p></xhtml>#;
 }
 
 1;
